@@ -6,16 +6,25 @@
 #'
 #' @param search_term A string specifying the term to search for in the PDB.
 #' @param field A string indicating the specific field to retrieve for each search result.
-#'   Default is "citation".
+#'   Default is "citation". Other options are 'audit_author', 'cell', 'diffrn', 'diffrn_detector',
+#'   'diffrn_radiation', 'diffrn_source', 'entry', 'exptl', 'exptl_crystal', 'exptl_crystal_grow', 'pdbx_sgproject',
+#'   'pdbx_audit_revision_details', 'pdbx_audit_revision_history', 'pdbx_database_related', 'pdbx_database_status',
+#'   'rcsb_accession_info', 'rcsb_entry_container_identifiers', 'rcsb_entry_info', 'rcsb_primary_citation', 'refine',
+#'   'refine_hist', 'refine_ls_restr', 'reflns', 'reflns_shell', 'software', 'struct', 'struct_keywords', 'symmetry',
+#'   'rcsb_id'
 #' @return A named list where each element's name is a PDB ID and its value is the information
 #'   for the specified field from the corresponding search result.
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET
+#' @examples
+#' \donttest{
+#' find_results("crispr", field = "citation")
+#'}
 #' @export
 find_results <- function(search_term, field = "citation") {
 
   # Retrieve search result IDs
-  search_result_ids <- query_search(search_term)[[1]]
+  search_result_ids <- query_search(search_term)
 
   # Initialize a list to store results
   all_results <- list()
